/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
/**
 * Provides the central classes used for configuring and accessing the BonSAI
 * system.
 *
 * <p>
 * All classes and interfaces provided here are middleware-independent.
 * </p>
 * 
 * <p>
 * {@link de.unibi.airobots.bonsai.core.BonsaiManager} is the central entry
 * point to the BonSAI system. It parses a user-specified configuration into a
 * set of valid {@link de.unibi.airobots.bonsai.core.Sensor}s and
 * {@link de.unibi.airobots.bonsai.core.Actuator}s and provides methods to
 * retrieve new instances of the Sensors or Actuators.
 * </p>
 * 
 * <p>
 * A {@link de.unibi.airobots.bonsai.core.Sensor} represents some kind of
 * information providing system of the robot more or less without manipulating
 * the environment. An {@link de.unibi.airobots.bonsai.core.Actuator} in
 * contrast is essentially manipulating the robot or the environment.
 * </p>
 * 
 * <p>
 * Sensors and Actuators are provided by implementations of
 * {@link de.unibi.airobots.bonsai.core.CoreObjectFactory}. These instances
 * provide middleware-specific implementations of the requested sensors or
 * actuators. A client program should only rely on the abstract middleware-
 * independent interfaces for Sensors or Actuators.
 * </p>
 * 
 * <p>
 * {@link de.unibi.airobots.bonsai.core.BonsaiManager} can be configured using
 * user-supplied configuration objects. The interfaces for these objects are
 * defined in {@link de.unibi.airobots.bonsai.core.configuration}.
 * </p>
 */

package de.unibi.airobots.bonsai.core;

