package de.unibi.airobots.bonsai.strategies.navigation;

import java.io.IOException;

import de.unibi.airobots.bonsai.strategies.navigation.SimpleNavigationStrategy.NotReachedException;
import de.unibi.airobots.bonsai.util.helper.GoalReachedWaiter.ReachStatus;
import de.unibi.airobots.btl.data.navigation.NavigationGoalData;
import de.unibi.airobots.btl.data.navigation.PositionData;

public interface NavigationStrategy {

	/**
	 * Tries to reach the given coordinates globally and, on failure, locally.
	 * 
	 * @param target
	 *            position to reach
	 * @throws NotReachedException
	 *             If the goal could not be reached, contains the ReachStatus.
	 * @throws IOException
	 *             If navigating fails.
	 */
	public void driveTo(PositionData target) throws NotReachedException,
			IOException;

	/**
	 * Tries to reach the given goal and returns the resulting status.
	 * 
	 * @param target
	 *            position to reach
	 * @return indicates whether the goal could be reached or not (and why)
	 * @throws IOException
	 *             if navigating fails
	 */
	public ReachStatus driveTo(NavigationGoalData target) throws IOException;

	/**
	 * Turns the robot.
	 * 
	 * @param angle
	 *            to turn
	 * @throws IOException
	 *             if navigating fails
	 * @throws NotReachedException
	 *             If the goal could not be reached, contains the ReachStatus.
	 */
	public void turn(double angle) throws IOException, NotReachedException;

}
